package com.ruoyi.report.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.report.mapper.RecordPlanrateamountDayMapper;
import com.ruoyi.report.domain.RecordPlanrateamountDay;
import com.ruoyi.report.service.IRecordPlanrateamountDayService;
import com.ruoyi.common.core.text.Convert;

/**
 * 计划完成率产量日报Service业务层处理
 * 
 * @author CaesarBao
 * @date 2020-11-04
 */
@Service
public class RecordPlanrateamountDayServiceImpl implements IRecordPlanrateamountDayService 
{
    @Autowired
    private RecordPlanrateamountDayMapper recordPlanrateamountDayMapper;

    /**
     * 查询计划完成率产量日报
     * 
     * @param objid 计划完成率产量日报ID
     * @return 计划完成率产量日报
     */
    @Override
    public RecordPlanrateamountDay selectRecordPlanrateamountDayById(Long objid)
    {
        return recordPlanrateamountDayMapper.selectRecordPlanrateamountDayById(objid);
    }

    /**
     * 查询计划完成率产量日报列表
     * 
     * @param recordPlanrateamountDay 计划完成率产量日报
     * @return 计划完成率产量日报
     */
    @Override
    public List<RecordPlanrateamountDay> selectRecordPlanrateamountDayList(RecordPlanrateamountDay recordPlanrateamountDay)
    {
        return recordPlanrateamountDayMapper.selectRecordPlanrateamountDayList(recordPlanrateamountDay);
    }

    /**
     * 新增计划完成率产量日报
     * 
     * @param recordPlanrateamountDay 计划完成率产量日报
     * @return 结果
     */
    @Override
    public int insertRecordPlanrateamountDay(RecordPlanrateamountDay recordPlanrateamountDay)
    {
        return recordPlanrateamountDayMapper.insertRecordPlanrateamountDay(recordPlanrateamountDay);
    }

    /**
     * 修改计划完成率产量日报
     * 
     * @param recordPlanrateamountDay 计划完成率产量日报
     * @return 结果
     */
    @Override
    public int updateRecordPlanrateamountDay(RecordPlanrateamountDay recordPlanrateamountDay)
    {
        return recordPlanrateamountDayMapper.updateRecordPlanrateamountDay(recordPlanrateamountDay);
    }

    /**
     * 删除计划完成率产量日报对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteRecordPlanrateamountDayByIds(String ids)
    {
        return recordPlanrateamountDayMapper.deleteRecordPlanrateamountDayByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除计划完成率产量日报信息
     * 
     * @param objid 计划完成率产量日报ID
     * @return 结果
     */
    @Override
    public int deleteRecordPlanrateamountDayById(Long objid)
    {
        return recordPlanrateamountDayMapper.deleteRecordPlanrateamountDayById(objid);
    }
}
